
Welcome to xotl.tools's documentation!
======================================

.. automodule:: xotl.tools

What's new in |release|
-----------------------

.. include:: history/3.0/_changes-3.0.0.rst


Contents
--------

.. toctree::
   :maxdepth: 1
   :glob:

   xotl.tools/*
   history/index.rst
   CONTRIBUTING
   CONTRIBUTORS
   LICENSE
   pre-history/index.rst


Indices and tables
==================

* `genindex`:ref:
* `search`:ref:
